Class: Google::Apis::CloudsupportV2beta::Case
- Inherits:
-
Object
- Object
- Google::Apis::CloudsupportV2beta::Case
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsupport_v2beta/classes.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb
Overview
A Case is an object that contains the details of a support case. It contains
fields for the time it was created, its priority, its classification, and more.
Cases can also have comments and attachments that get added over time. A case
is parented by a Google Cloud organization or project. Organizations are
identified by a number, so the name of a case parented by an organization
would look like this: organizations/123/cases/456 Projects have two
unique identifiers, an ID and a number, and they look like this: projects/
abc/cases/456 projects/123/cases/456 You can use either of them
when calling the API. To learn more about project identifiers, see AIP-2510.
Instance Attribute Summary collapse
-
#classification ⇒ Google::Apis::CloudsupportV2beta::CaseClassification
A Case Classification represents the topic that a case is about.
-
#contact_email ⇒ String
A user-supplied email address to send case update notifications for.
-
#create_time ⇒ String
Output only.
-
#creator ⇒ Google::Apis::CloudsupportV2beta::Actor
An Actor represents an entity that performed an action.
-
#description ⇒ String
A broad description of the issue.
-
#display_name ⇒ String
The short summary of the issue reported in this case.
-
#escalated ⇒ Boolean
(also: #escalated?)
Whether the case is currently escalated.
-
#language_code ⇒ String
The language the user has requested to receive support in.
-
#name ⇒ String
Identifier.
-
#priority ⇒ String
The priority of this case.
-
#severity ⇒ String
REMOVED.
-
#state ⇒ String
Output only.
-
#subscriber_email_addresses ⇒ Array<String>
The email addresses to receive updates on this case.
-
#test_case ⇒ Boolean
(also: #test_case?)
Whether this case was created for internal API testing and should not be acted on by the support team.
-
#time_zone ⇒ String
The timezone of the user who created the support case.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Case
constructor
A new instance of Case.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Case
Returns a new instance of Case.
299 300 301 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 299 def initialize(**args) update!(**args) end |
Instance Attribute Details
#classification ⇒ Google::Apis::CloudsupportV2beta::CaseClassification
A Case Classification represents the topic that a case is about. It's very
important to use accurate classifications, because they're used to route your
cases to specialists who can help you. A classification always has an ID that
is its unique identifier. A valid ID is required when creating a case.
Corresponds to the JSON property classification
207 208 209 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 207 def classification @classification end |
#contact_email ⇒ String
A user-supplied email address to send case update notifications for. This
should only be used in BYOID flows, where we cannot infer the user's email
address directly from their EUCs.
Corresponds to the JSON property contactEmail
214 215 216 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 214 def contact_email @contact_email end |
#create_time ⇒ String
Output only. The time this case was created.
Corresponds to the JSON property createTime
219 220 221 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 219 def create_time @create_time end |
#creator ⇒ Google::Apis::CloudsupportV2beta::Actor
An Actor represents an entity that performed an action. For example, an actor
could be a user who posted a comment on a support case, a user who uploaded an
attachment, or a service account that created a support case.
Corresponds to the JSON property creator
226 227 228 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 226 def creator @creator end |
#description ⇒ String
A broad description of the issue.
Corresponds to the JSON property description
231 232 233 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 231 def description @description end |
#display_name ⇒ String
The short summary of the issue reported in this case.
Corresponds to the JSON property displayName
236 237 238 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 236 def display_name @display_name end |
#escalated ⇒ Boolean Also known as: escalated?
Whether the case is currently escalated.
Corresponds to the JSON property escalated
241 242 243 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 241 def escalated @escalated end |
#language_code ⇒ String
The language the user has requested to receive support in. This should be a
BCP 47 language code (e.g., "en", "zh-CN", "zh-TW", "ja", "ko"). If
no language or an unsupported language is specified, this field defaults to
English (en). Language selection during case creation may affect your
available support options. For a list of supported languages and their support
working hours, see: https://cloud.google.com/support/docs/language-working-
hours
Corresponds to the JSON property languageCode
253 254 255 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 253 def language_code @language_code end |
#name ⇒ String
Identifier. The resource name for the case.
Corresponds to the JSON property name
258 259 260 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 258 def name @name end |
#priority ⇒ String
The priority of this case.
Corresponds to the JSON property priority
263 264 265 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 263 def priority @priority end |
#severity ⇒ String
REMOVED. The severity of this case. Use priority instead.
Corresponds to the JSON property severity
268 269 270 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 268 def severity @severity end |
#state ⇒ String
Output only. The current status of the support case.
Corresponds to the JSON property state
273 274 275 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 273 def state @state end |
#subscriber_email_addresses ⇒ Array<String>
The email addresses to receive updates on this case.
Corresponds to the JSON property subscriberEmailAddresses
278 279 280 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 278 def subscriber_email_addresses @subscriber_email_addresses end |
#test_case ⇒ Boolean Also known as: test_case?
Whether this case was created for internal API testing and should not be acted
on by the support team.
Corresponds to the JSON property testCase
284 285 286 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 284 def test_case @test_case end |
#time_zone ⇒ String
The timezone of the user who created the support case. It should be in a
format IANA recognizes: https://www.iana.org/time-zones. There is no
additional validation done by the API.
Corresponds to the JSON property timeZone
292 293 294 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 292 def time_zone @time_zone end |
#update_time ⇒ String
Output only. The time this case was last updated.
Corresponds to the JSON property updateTime
297 298 299 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 297 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 304 def update!(**args) @classification = args[:classification] if args.key?(:classification) @contact_email = args[:contact_email] if args.key?(:contact_email) @create_time = args[:create_time] if args.key?(:create_time) @creator = args[:creator] if args.key?(:creator) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @escalated = args[:escalated] if args.key?(:escalated) @language_code = args[:language_code] if args.key?(:language_code) @name = args[:name] if args.key?(:name) @priority = args[:priority] if args.key?(:priority) @severity = args[:severity] if args.key?(:severity) @state = args[:state] if args.key?(:state) @subscriber_email_addresses = args[:subscriber_email_addresses] if args.key?(:subscriber_email_addresses) @test_case = args[:test_case] if args.key?(:test_case) @time_zone = args[:time_zone] if args.key?(:time_zone) @update_time = args[:update_time] if args.key?(:update_time) end |