Class: Google::Apis::CloudsupportV2beta::CompositeMedia
- Inherits:
-
Object
- Object
- Google::Apis::CloudsupportV2beta::CompositeMedia
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsupport_v2beta/classes.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb
Overview
gdata.* are outside protos with mising documentation
Instance Attribute Summary collapse
-
#blob_ref ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
blobRefNOTE: Values are automatically base64 encoded/decoded in the client library. -
#blobstore2_info ⇒ Google::Apis::CloudsupportV2beta::Blobstore2Info
gdata.* are outside protos with mising documentation Corresponds to the JSON property
blobstore2Info. -
#cosmo_binary_reference ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
cosmoBinaryReferenceNOTE: Values are automatically base64 encoded/decoded in the client library. -
#crc32c_hash ⇒ Fixnum
gdata.* are outside protos with mising documentation Corresponds to the JSON property
crc32cHash. -
#inline ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
inlineNOTE: Values are automatically base64 encoded/decoded in the client library. -
#length ⇒ Fixnum
gdata.* are outside protos with mising documentation Corresponds to the JSON property
length. -
#md5_hash ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
md5HashNOTE: Values are automatically base64 encoded/decoded in the client library. -
#object_id_prop ⇒ Google::Apis::CloudsupportV2beta::ObjectIdProp
gdata.* are outside protos with mising documentation Corresponds to the JSON property
objectId. -
#path ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
path. -
#reference_type ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
referenceType. -
#sha1_hash ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
sha1HashNOTE: Values are automatically base64 encoded/decoded in the client library.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompositeMedia
constructor
A new instance of CompositeMedia.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompositeMedia
Returns a new instance of CompositeMedia.
490 491 492 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 490 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blob_ref ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property blobRef
NOTE: Values are automatically base64 encoded/decoded in the client library.
434 435 436 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 434 def blob_ref @blob_ref end |
#blobstore2_info ⇒ Google::Apis::CloudsupportV2beta::Blobstore2Info
gdata.* are outside protos with mising documentation
Corresponds to the JSON property blobstore2Info
439 440 441 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 439 def blobstore2_info @blobstore2_info end |
#cosmo_binary_reference ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property cosmoBinaryReference
NOTE: Values are automatically base64 encoded/decoded in the client library.
445 446 447 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 445 def cosmo_binary_reference @cosmo_binary_reference end |
#crc32c_hash ⇒ Fixnum
gdata.* are outside protos with mising documentation
Corresponds to the JSON property crc32cHash
450 451 452 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 450 def crc32c_hash @crc32c_hash end |
#inline ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property inline
NOTE: Values are automatically base64 encoded/decoded in the client library.
456 457 458 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 456 def inline @inline end |
#length ⇒ Fixnum
gdata.* are outside protos with mising documentation
Corresponds to the JSON property length
461 462 463 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 461 def length @length end |
#md5_hash ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property md5Hash
NOTE: Values are automatically base64 encoded/decoded in the client library.
467 468 469 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 467 def md5_hash @md5_hash end |
#object_id_prop ⇒ Google::Apis::CloudsupportV2beta::ObjectIdProp
gdata.* are outside protos with mising documentation
Corresponds to the JSON property objectId
472 473 474 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 472 def object_id_prop @object_id_prop end |
#path ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property path
477 478 479 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 477 def path @path end |
#reference_type ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property referenceType
482 483 484 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 482 def reference_type @reference_type end |
#sha1_hash ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property sha1Hash
NOTE: Values are automatically base64 encoded/decoded in the client library.
488 489 490 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 488 def sha1_hash @sha1_hash end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
495 496 497 498 499 500 501 502 503 504 505 506 507 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 495 def update!(**args) @blob_ref = args[:blob_ref] if args.key?(:blob_ref) @blobstore2_info = args[:blobstore2_info] if args.key?(:blobstore2_info) @cosmo_binary_reference = args[:cosmo_binary_reference] if args.key?(:cosmo_binary_reference) @crc32c_hash = args[:crc32c_hash] if args.key?(:crc32c_hash) @inline = args[:inline] if args.key?(:inline) @length = args[:length] if args.key?(:length) @md5_hash = args[:md5_hash] if args.key?(:md5_hash) @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop) @path = args[:path] if args.key?(:path) @reference_type = args[:reference_type] if args.key?(:reference_type) @sha1_hash = args[:sha1_hash] if args.key?(:sha1_hash) end |