Class: Google::Apis::CloudsupportV2beta::CreateAttachmentRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudsupportV2beta::CreateAttachmentRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsupport_v2beta/classes.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb
Overview
The request message for the CreateAttachment endpoint.
Instance Attribute Summary collapse
-
#attachment ⇒ Google::Apis::CloudsupportV2beta::Attachment
An Attachment contains metadata about a file that was uploaded to a case - it is NOT a file itself.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateAttachmentRequest
constructor
A new instance of CreateAttachmentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateAttachmentRequest
Returns a new instance of CreateAttachmentRequest.
579 580 581 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 579 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment ⇒ Google::Apis::CloudsupportV2beta::Attachment
An Attachment contains metadata about a file that was uploaded to a case - it
is NOT a file itself. That being said, the name of an Attachment object can be
used to download its accompanying file through the media.download endpoint.
While attachments can be uploaded in the console at the same time as a comment,
they're associated on a "case" level, not a "comment" level.
Corresponds to the JSON property attachment
577 578 579 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 577 def @attachment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
584 585 586 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 584 def update!(**args) @attachment = args[:attachment] if args.key?(:attachment) end |