Class: Google::Apis::CloudsupportV2beta::EmailMessage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsupport_v2beta/classes.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb

Overview

An email associated with a support case.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EmailMessage

Returns a new instance of EmailMessage.



800
801
802
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 800

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actorGoogle::Apis::CloudsupportV2beta::Actor

An Actor represents an entity that performed an action. For example, an actor could be a user who posted a comment on a support case, a user who uploaded an attachment, or a service account that created a support case. Corresponds to the JSON property actor



768
769
770
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 768

def actor
  @actor
end

#body_contentGoogle::Apis::CloudsupportV2beta::TextContent

Stores text attached to a support object. Corresponds to the JSON property bodyContent



773
774
775
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 773

def body_content
  @body_content
end

#cc_email_addressesArray<String>

Output only. Email addresses CCed on the email. Corresponds to the JSON property ccEmailAddresses

Returns:

  • (Array<String>)


778
779
780
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 778

def cc_email_addresses
  @cc_email_addresses
end

#create_timeString

Output only. Time when this email message object was created. Corresponds to the JSON property createTime

Returns:

  • (String)


783
784
785
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 783

def create_time
  @create_time
end

#nameString

Identifier. Resource name for the email message. Corresponds to the JSON property name

Returns:

  • (String)


788
789
790
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 788

def name
  @name
end

#recipient_email_addressesArray<String>

Output only. Email addresses the email was sent to. Corresponds to the JSON property recipientEmailAddresses

Returns:

  • (Array<String>)


793
794
795
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 793

def recipient_email_addresses
  @recipient_email_addresses
end

#subjectString

Output only. Subject of the email. Corresponds to the JSON property subject

Returns:

  • (String)


798
799
800
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 798

def subject
  @subject
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



805
806
807
808
809
810
811
812
813
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 805

def update!(**args)
  @actor = args[:actor] if args.key?(:actor)
  @body_content = args[:body_content] if args.key?(:body_content)
  @cc_email_addresses = args[:cc_email_addresses] if args.key?(:cc_email_addresses)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @recipient_email_addresses = args[:recipient_email_addresses] if args.key?(:recipient_email_addresses)
  @subject = args[:subject] if args.key?(:subject)
end