Class: Google::Apis::CloudsupportV2beta::Escalation
- Inherits:
-
Object
- Object
- Google::Apis::CloudsupportV2beta::Escalation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsupport_v2beta/classes.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb
Overview
An escalation of a support case.
Instance Attribute Summary collapse
-
#justification ⇒ String
Required.
-
#reason ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Escalation
constructor
A new instance of Escalation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Escalation
Returns a new instance of Escalation.
830 831 832 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#justification ⇒ String
Required. A free text description to accompany the reason field above.
Provides additional context on why the case is being escalated.
Corresponds to the JSON property justification
823 824 825 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 823 def justification @justification end |
#reason ⇒ String
Required. The reason why the Case is being escalated.
Corresponds to the JSON property reason
828 829 830 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 828 def reason @reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
835 836 837 838 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 835 def update!(**args) @justification = args[:justification] if args.key?(:justification) @reason = args[:reason] if args.key?(:reason) end |