Class: Google::Apis::CloudsupportV2beta::SearchCaseClassificationsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsupport_v2beta/classes.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb

Overview

The response message for SearchCaseClassifications endpoint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchCaseClassificationsResponse

Returns a new instance of SearchCaseClassificationsResponse.



1298
1299
1300
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#case_classificationsArray<Google::Apis::CloudsupportV2beta::CaseClassification>

The classifications retrieved. Corresponds to the JSON property caseClassifications



1289
1290
1291
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1289

def case_classifications
  @case_classifications
end

#next_page_tokenString

A token to retrieve the next page of results. Set this in the page_token field of subsequent caseClassifications.list requests. If unspecified, there are no more results to retrieve. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1296
1297
1298
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1296

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1303
1304
1305
1306
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1303

def update!(**args)
  @case_classifications = args[:case_classifications] if args.key?(:case_classifications)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end