Class: Google::Apis::CloudsupportV2beta::SupportEventSubscription

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsupport_v2beta/classes.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb

Overview

A support event subscription.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SupportEventSubscription

Returns a new instance of SupportEventSubscription.



1410
1411
1412
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the subscription was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1371
1372
1373
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1371

def create_time
  @create_time
end

#delete_timeString

Output only. The time at which the subscription was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


1376
1377
1378
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1376

def delete_time
  @delete_time
end

#failure_reasonString

Output only. Reason why subscription is failing. State of subscription must be FAILING in order for this to have a value. Corresponds to the JSON property failureReason

Returns:

  • (String)


1382
1383
1384
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1382

def failure_reason
  @failure_reason
end

#nameString

Identifier. The resource name of the support event subscription. Corresponds to the JSON property name

Returns:

  • (String)


1387
1388
1389
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1387

def name
  @name
end

#pub_sub_topicString

Required. The name of the Pub/Sub topic to publish notifications to. Format: projects/project/topics/topic Corresponds to the JSON property pubSubTopic

Returns:

  • (String)


1393
1394
1395
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1393

def pub_sub_topic
  @pub_sub_topic
end

#purge_timeString

Output only. The time at which the subscription will be purged. Corresponds to the JSON property purgeTime

Returns:

  • (String)


1398
1399
1400
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1398

def purge_time
  @purge_time
end

#stateString

Output only. The state of the subscription. Corresponds to the JSON property state

Returns:

  • (String)


1403
1404
1405
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1403

def state
  @state
end

#update_timeString

Output only. The time at which the subscription was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1408
1409
1410
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1408

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1415

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @name = args[:name] if args.key?(:name)
  @pub_sub_topic = args[:pub_sub_topic] if args.key?(:pub_sub_topic)
  @purge_time = args[:purge_time] if args.key?(:purge_time)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end