Class: Google::Apis::CloudsupportV2beta::Case

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsupport_v2beta/classes.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb

Overview

A Case is an object that contains the details of a support case. It contains fields for the time it was created, its priority, its classification, and more. Cases can also have comments and attachments that get added over time. A case is parented by a Google Cloud organization or project. Organizations are identified by a number, so the name of a case parented by an organization would look like this: organizations/123/cases/456 Projects have two unique identifiers, an ID and a number, and they look like this: projects/ abc/cases/456 projects/123/cases/456 You can use either of them when calling the API. To learn more about project identifiers, see AIP-2510.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Case

Returns a new instance of Case.



292
293
294
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 292

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#classificationGoogle::Apis::CloudsupportV2beta::CaseClassification

A Case Classification represents the topic that a case is about. It's very important to use accurate classifications, because they're used to route your cases to specialists who can help you. A classification always has an ID that is its unique identifier. A valid ID is required when creating a case. Corresponds to the JSON property classification



200
201
202
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 200

def classification
  @classification
end

#contact_emailString

A user-supplied email address to send case update notifications for. This should only be used in BYOID flows, where we cannot infer the user's email address directly from their EUCs. Corresponds to the JSON property contactEmail

Returns:

  • (String)


207
208
209
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 207

def contact_email
  @contact_email
end

#create_timeString

Output only. The time this case was created. Corresponds to the JSON property createTime

Returns:

  • (String)


212
213
214
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 212

def create_time
  @create_time
end

#creatorGoogle::Apis::CloudsupportV2beta::Actor

An Actor represents an entity that performed an action. For example, an actor could be a user who posted a comment on a support case, a user who uploaded an attachment, or a service account that created a support case. Corresponds to the JSON property creator



219
220
221
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 219

def creator
  @creator
end

#descriptionString

A broad description of the issue. Corresponds to the JSON property description

Returns:

  • (String)


224
225
226
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 224

def description
  @description
end

#display_nameString

The short summary of the issue reported in this case. Corresponds to the JSON property displayName

Returns:

  • (String)


229
230
231
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 229

def display_name
  @display_name
end

#escalatedBoolean Also known as: escalated?

Whether the case is currently escalated. Corresponds to the JSON property escalated

Returns:

  • (Boolean)


234
235
236
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 234

def escalated
  @escalated
end

#language_codeString

The language the user has requested to receive support in. This should be a BCP 47 language code (e.g., "en", "zh-CN", "zh-TW", "ja", "ko"). If no language or an unsupported language is specified, this field defaults to English (en). Language selection during case creation may affect your available support options. For a list of supported languages and their support working hours, see: https://cloud.google.com/support/docs/language-working- hours Corresponds to the JSON property languageCode

Returns:

  • (String)


246
247
248
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 246

def language_code
  @language_code
end

#nameString

Identifier. The resource name for the case. Corresponds to the JSON property name

Returns:

  • (String)


251
252
253
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 251

def name
  @name
end

#priorityString

The priority of this case. Corresponds to the JSON property priority

Returns:

  • (String)


256
257
258
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 256

def priority
  @priority
end

#severityString

REMOVED. The severity of this case. Use priority instead. Corresponds to the JSON property severity

Returns:

  • (String)


261
262
263
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 261

def severity
  @severity
end

#stateString

Output only. The current status of the support case. Corresponds to the JSON property state

Returns:

  • (String)


266
267
268
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 266

def state
  @state
end

#subscriber_email_addressesArray<String>

The email addresses to receive updates on this case. Corresponds to the JSON property subscriberEmailAddresses

Returns:

  • (Array<String>)


271
272
273
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 271

def subscriber_email_addresses
  @subscriber_email_addresses
end

#test_caseBoolean Also known as: test_case?

Whether this case was created for internal API testing and should not be acted on by the support team. Corresponds to the JSON property testCase

Returns:

  • (Boolean)


277
278
279
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 277

def test_case
  @test_case
end

#time_zoneString

The timezone of the user who created the support case. It should be in a format IANA recognizes: https://www.iana.org/time-zones. There is no additional validation done by the API. Corresponds to the JSON property timeZone

Returns:

  • (String)


285
286
287
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 285

def time_zone
  @time_zone
end

#update_timeString

Output only. The time this case was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


290
291
292
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 290

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 297

def update!(**args)
  @classification = args[:classification] if args.key?(:classification)
  @contact_email = args[:contact_email] if args.key?(:contact_email)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator = args[:creator] if args.key?(:creator)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @escalated = args[:escalated] if args.key?(:escalated)
  @language_code = args[:language_code] if args.key?(:language_code)
  @name = args[:name] if args.key?(:name)
  @priority = args[:priority] if args.key?(:priority)
  @severity = args[:severity] if args.key?(:severity)
  @state = args[:state] if args.key?(:state)
  @subscriber_email_addresses = args[:subscriber_email_addresses] if args.key?(:subscriber_email_addresses)
  @test_case = args[:test_case] if args.key?(:test_case)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @update_time = args[:update_time] if args.key?(:update_time)
end