Class: Google::Apis::CloudsupportV2beta::CaseClassification

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsupport_v2beta/classes.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb

Overview

A Case Classification represents the topic that a case is about. It's very important to use accurate classifications, because they're used to route your cases to specialists who can help you. A classification always has an ID that is its unique identifier. A valid ID is required when creating a case.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CaseClassification

Returns a new instance of CaseClassification.



346
347
348
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

A display name for the classification. The display name is not static and can change. To uniquely and consistently identify classifications, use the CaseClassification.id field. Corresponds to the JSON property displayName

Returns:

  • (String)


329
330
331
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 329

def display_name
  @display_name
end

#idString

The unique ID for a classification. Must be specified for case creation. To retrieve valid classification IDs for case creation, use caseClassifications. search. Classification IDs returned by caseClassifications.search are guaranteed to be valid for at least 6 months. If a given classification is deactiveated, it will immediately stop being returned. After 6 months, case. create requests using the classification ID will fail. Corresponds to the JSON property id

Returns:

  • (String)


339
340
341
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 339

def id
  @id
end

#productGoogle::Apis::CloudsupportV2beta::Product

The product a case may be associated with. Corresponds to the JSON property product



344
345
346
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 344

def product
  @product
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



351
352
353
354
355
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 351

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @product = args[:product] if args.key?(:product)
end