Class: Google::Apis::CloudsupportV2beta::EmailMessage
- Inherits:
-
Object
- Object
- Google::Apis::CloudsupportV2beta::EmailMessage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsupport_v2beta/classes.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb
Overview
An email associated with a support case.
Instance Attribute Summary collapse
-
#actor ⇒ Google::Apis::CloudsupportV2beta::Actor
An Actor represents an entity that performed an action.
-
#body_content ⇒ Google::Apis::CloudsupportV2beta::TextContent
Stores text attached to a support object.
-
#cc_email_addresses ⇒ Array<String>
Output only.
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#recipient_email_addresses ⇒ Array<String>
Output only.
-
#subject ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EmailMessage
constructor
A new instance of EmailMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EmailMessage
Returns a new instance of EmailMessage.
780 781 782 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 780 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actor ⇒ Google::Apis::CloudsupportV2beta::Actor
An Actor represents an entity that performed an action. For example, an actor
could be a user who posted a comment on a support case, a user who uploaded an
attachment, or a service account that created a support case.
Corresponds to the JSON property actor
748 749 750 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 748 def actor @actor end |
#body_content ⇒ Google::Apis::CloudsupportV2beta::TextContent
Stores text attached to a support object.
Corresponds to the JSON property bodyContent
753 754 755 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 753 def body_content @body_content end |
#cc_email_addresses ⇒ Array<String>
Output only. Email addresses CCed on the email.
Corresponds to the JSON property ccEmailAddresses
758 759 760 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 758 def cc_email_addresses @cc_email_addresses end |
#create_time ⇒ String
Output only. Time when this email message object was created.
Corresponds to the JSON property createTime
763 764 765 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 763 def create_time @create_time end |
#name ⇒ String
Identifier. Resource name for the email message.
Corresponds to the JSON property name
768 769 770 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 768 def name @name end |
#recipient_email_addresses ⇒ Array<String>
Output only. Email addresses the email was sent to.
Corresponds to the JSON property recipientEmailAddresses
773 774 775 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 773 def recipient_email_addresses @recipient_email_addresses end |
#subject ⇒ String
Output only. Subject of the email.
Corresponds to the JSON property subject
778 779 780 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 778 def subject @subject end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
785 786 787 788 789 790 791 792 793 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 785 def update!(**args) @actor = args[:actor] if args.key?(:actor) @body_content = args[:body_content] if args.key?(:body_content) @cc_email_addresses = args[:cc_email_addresses] if args.key?(:cc_email_addresses) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @recipient_email_addresses = args[:recipient_email_addresses] if args.key?(:recipient_email_addresses) @subject = args[:subject] if args.key?(:subject) end |