Class: Google::Apis::CloudsupportV2beta::FeedItem
- Inherits:
-
Object
- Object
- Google::Apis::CloudsupportV2beta::FeedItem
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsupport_v2beta/classes.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb
Overview
A feed item associated with a support case.
Instance Attribute Summary collapse
-
#attachment ⇒ Google::Apis::CloudsupportV2beta::Attachment
An Attachment contains metadata about a file that was uploaded to a case - it is NOT a file itself.
-
#comment ⇒ Google::Apis::CloudsupportV2beta::Comment
A comment associated with a support case.
-
#deleted_attachment ⇒ Google::Apis::CloudsupportV2beta::Attachment
An Attachment contains metadata about a file that was uploaded to a case - it is NOT a file itself.
-
#email_message ⇒ Google::Apis::CloudsupportV2beta::EmailMessage
An email associated with a support case.
-
#event_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FeedItem
constructor
A new instance of FeedItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FeedItem
Returns a new instance of FeedItem.
929 930 931 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 929 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment ⇒ Google::Apis::CloudsupportV2beta::Attachment
An Attachment contains metadata about a file that was uploaded to a case - it
is NOT a file itself. That being said, the name of an Attachment object can be
used to download its accompanying file through the media.download endpoint.
While attachments can be uploaded in the console at the same time as a comment,
they're associated on a "case" level, not a "comment" level.
Corresponds to the JSON property attachment
901 902 903 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 901 def @attachment end |
#comment ⇒ Google::Apis::CloudsupportV2beta::Comment
A comment associated with a support case. Case comments are the primary way
for Google Support to communicate with a user who has opened a case. When a
user responds to Google Support, the user's responses also appear as comments.
Corresponds to the JSON property comment
908 909 910 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 908 def comment @comment end |
#deleted_attachment ⇒ Google::Apis::CloudsupportV2beta::Attachment
An Attachment contains metadata about a file that was uploaded to a case - it
is NOT a file itself. That being said, the name of an Attachment object can be
used to download its accompanying file through the media.download endpoint.
While attachments can be uploaded in the console at the same time as a comment,
they're associated on a "case" level, not a "comment" level.
Corresponds to the JSON property deletedAttachment
917 918 919 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 917 def @deleted_attachment end |
#email_message ⇒ Google::Apis::CloudsupportV2beta::EmailMessage
An email associated with a support case.
Corresponds to the JSON property emailMessage
922 923 924 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 922 def @email_message end |
#event_time ⇒ String
Output only. Time corresponding to the event of this item.
Corresponds to the JSON property eventTime
927 928 929 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 927 def event_time @event_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
934 935 936 937 938 939 940 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 934 def update!(**args) @attachment = args[:attachment] if args.key?(:attachment) @comment = args[:comment] if args.key?(:comment) @deleted_attachment = args[:deleted_attachment] if args.key?(:deleted_attachment) @email_message = args[:email_message] if args.key?(:email_message) @event_time = args[:event_time] if args.key?(:event_time) end |