Class: Google::Apis::CloudsupportV2beta::FeedItem
- Inherits:
-
Object
- Object
- Google::Apis::CloudsupportV2beta::FeedItem
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsupport_v2beta/classes.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb
Overview
A feed item associated with a support case.
Instance Attribute Summary collapse
-
#attachment ⇒ Google::Apis::CloudsupportV2beta::Attachment
An Attachment contains metadata about a file that was uploaded to a case - it is NOT a file itself.
-
#comment ⇒ Google::Apis::CloudsupportV2beta::Comment
A comment associated with a support case.
-
#deleted_attachment ⇒ Google::Apis::CloudsupportV2beta::Attachment
An Attachment contains metadata about a file that was uploaded to a case - it is NOT a file itself.
-
#email_message ⇒ Google::Apis::CloudsupportV2beta::EmailMessage
An email associated with a support case.
-
#event_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FeedItem
constructor
A new instance of FeedItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FeedItem
Returns a new instance of FeedItem.
880 881 882 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 880 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment ⇒ Google::Apis::CloudsupportV2beta::Attachment
An Attachment contains metadata about a file that was uploaded to a case - it
is NOT a file itself. That being said, the name of an Attachment object can be
used to download its accompanying file through the media.download endpoint.
While attachments can be uploaded in the console at the same time as a comment,
they're associated on a "case" level, not a "comment" level.
Corresponds to the JSON property attachment
852 853 854 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 852 def @attachment end |
#comment ⇒ Google::Apis::CloudsupportV2beta::Comment
A comment associated with a support case. Case comments are the primary way
for Google Support to communicate with a user who has opened a case. When a
user responds to Google Support, the user's responses also appear as comments.
Corresponds to the JSON property comment
859 860 861 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 859 def comment @comment end |
#deleted_attachment ⇒ Google::Apis::CloudsupportV2beta::Attachment
An Attachment contains metadata about a file that was uploaded to a case - it
is NOT a file itself. That being said, the name of an Attachment object can be
used to download its accompanying file through the media.download endpoint.
While attachments can be uploaded in the console at the same time as a comment,
they're associated on a "case" level, not a "comment" level.
Corresponds to the JSON property deletedAttachment
868 869 870 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 868 def @deleted_attachment end |
#email_message ⇒ Google::Apis::CloudsupportV2beta::EmailMessage
An email associated with a support case.
Corresponds to the JSON property emailMessage
873 874 875 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 873 def @email_message end |
#event_time ⇒ String
Output only. Time corresponding to the event of this item.
Corresponds to the JSON property eventTime
878 879 880 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 878 def event_time @event_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
885 886 887 888 889 890 891 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 885 def update!(**args) @attachment = args[:attachment] if args.key?(:attachment) @comment = args[:comment] if args.key?(:comment) @deleted_attachment = args[:deleted_attachment] if args.key?(:deleted_attachment) @email_message = args[:email_message] if args.key?(:email_message) @event_time = args[:event_time] if args.key?(:event_time) end |