Class: Google::Apis::CloudsupportV2beta::Media
- Inherits:
-
Object
- Object
- Google::Apis::CloudsupportV2beta::Media
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsupport_v2beta/classes.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb
Overview
gdata.* are outside protos with mising documentation
Instance Attribute Summary collapse
-
#algorithm ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
algorithm. -
#bigstore_object_ref ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
bigstoreObjectRefNOTE: Values are automatically base64 encoded/decoded in the client library. -
#blob_ref ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
blobRefNOTE: Values are automatically base64 encoded/decoded in the client library. -
#blobstore2_info ⇒ Google::Apis::CloudsupportV2beta::Blobstore2Info
gdata.* are outside protos with mising documentation Corresponds to the JSON property
blobstore2Info. -
#composite_media ⇒ Array<Google::Apis::CloudsupportV2beta::CompositeMedia>
gdata.* are outside protos with mising documentation Corresponds to the JSON property
compositeMedia. -
#content_type ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
contentType. -
#content_type_info ⇒ Google::Apis::CloudsupportV2beta::ContentTypeInfo
gdata.* are outside protos with mising documentation Corresponds to the JSON property
contentTypeInfo. -
#cosmo_binary_reference ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
cosmoBinaryReferenceNOTE: Values are automatically base64 encoded/decoded in the client library. -
#crc32c_hash ⇒ Fixnum
gdata.* are outside protos with mising documentation Corresponds to the JSON property
crc32cHash. -
#diff_checksums_response ⇒ Google::Apis::CloudsupportV2beta::DiffChecksumsResponse
gdata.* are outside protos with mising documentation Corresponds to the JSON property
diffChecksumsResponse. -
#diff_download_response ⇒ Google::Apis::CloudsupportV2beta::DiffDownloadResponse
gdata.* are outside protos with mising documentation Corresponds to the JSON property
diffDownloadResponse. -
#diff_upload_request ⇒ Google::Apis::CloudsupportV2beta::DiffUploadRequest
gdata.* are outside protos with mising documentation Corresponds to the JSON property
diffUploadRequest. -
#diff_upload_response ⇒ Google::Apis::CloudsupportV2beta::DiffUploadResponse
gdata.* are outside protos with mising documentation Corresponds to the JSON property
diffUploadResponse. -
#diff_version_response ⇒ Google::Apis::CloudsupportV2beta::DiffVersionResponse
gdata.* are outside protos with mising documentation Corresponds to the JSON property
diffVersionResponse. -
#download_parameters ⇒ Google::Apis::CloudsupportV2beta::DownloadParameters
gdata.* are outside protos with mising documentation Corresponds to the JSON property
downloadParameters. -
#filename ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
filename. -
#hash_prop ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
hash. -
#hash_verified ⇒ Boolean
(also: #hash_verified?)
gdata.* are outside protos with mising documentation Corresponds to the JSON property
hashVerified. -
#inline ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
inlineNOTE: Values are automatically base64 encoded/decoded in the client library. -
#is_potential_retry ⇒ Boolean
(also: #is_potential_retry?)
gdata.* are outside protos with mising documentation Corresponds to the JSON property
isPotentialRetry. -
#length ⇒ Fixnum
gdata.* are outside protos with mising documentation Corresponds to the JSON property
length. -
#md5_hash ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
md5HashNOTE: Values are automatically base64 encoded/decoded in the client library. -
#media_id ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
mediaIdNOTE: Values are automatically base64 encoded/decoded in the client library. -
#object_id_prop ⇒ Google::Apis::CloudsupportV2beta::ObjectIdProp
gdata.* are outside protos with mising documentation Corresponds to the JSON property
objectId. -
#path ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
path. -
#reference_type ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
referenceType. -
#sha1_hash ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
sha1HashNOTE: Values are automatically base64 encoded/decoded in the client library. -
#sha256_hash ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
sha256HashNOTE: Values are automatically base64 encoded/decoded in the client library. -
#sha512_hash ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
sha512HashNOTE: Values are automatically base64 encoded/decoded in the client library. -
#timestamp ⇒ Fixnum
gdata.* are outside protos with mising documentation Corresponds to the JSON property
timestamp. -
#token ⇒ String
gdata.* are outside protos with mising documentation Corresponds to the JSON property
token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Media
constructor
A new instance of Media.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Media
Returns a new instance of Media.
1192 1193 1194 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1192 def initialize(**args) update!(**args) end |
Instance Attribute Details
#algorithm ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property algorithm
1029 1030 1031 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1029 def algorithm @algorithm end |
#bigstore_object_ref ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property bigstoreObjectRef
NOTE: Values are automatically base64 encoded/decoded in the client library.
1035 1036 1037 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1035 def bigstore_object_ref @bigstore_object_ref end |
#blob_ref ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property blobRef
NOTE: Values are automatically base64 encoded/decoded in the client library.
1041 1042 1043 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1041 def blob_ref @blob_ref end |
#blobstore2_info ⇒ Google::Apis::CloudsupportV2beta::Blobstore2Info
gdata.* are outside protos with mising documentation
Corresponds to the JSON property blobstore2Info
1046 1047 1048 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1046 def blobstore2_info @blobstore2_info end |
#composite_media ⇒ Array<Google::Apis::CloudsupportV2beta::CompositeMedia>
gdata.* are outside protos with mising documentation
Corresponds to the JSON property compositeMedia
1051 1052 1053 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1051 def composite_media @composite_media end |
#content_type ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property contentType
1056 1057 1058 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1056 def content_type @content_type end |
#content_type_info ⇒ Google::Apis::CloudsupportV2beta::ContentTypeInfo
gdata.* are outside protos with mising documentation
Corresponds to the JSON property contentTypeInfo
1061 1062 1063 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1061 def content_type_info @content_type_info end |
#cosmo_binary_reference ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property cosmoBinaryReference
NOTE: Values are automatically base64 encoded/decoded in the client library.
1067 1068 1069 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1067 def cosmo_binary_reference @cosmo_binary_reference end |
#crc32c_hash ⇒ Fixnum
gdata.* are outside protos with mising documentation
Corresponds to the JSON property crc32cHash
1072 1073 1074 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1072 def crc32c_hash @crc32c_hash end |
#diff_checksums_response ⇒ Google::Apis::CloudsupportV2beta::DiffChecksumsResponse
gdata.* are outside protos with mising documentation
Corresponds to the JSON property diffChecksumsResponse
1077 1078 1079 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1077 def diff_checksums_response @diff_checksums_response end |
#diff_download_response ⇒ Google::Apis::CloudsupportV2beta::DiffDownloadResponse
gdata.* are outside protos with mising documentation
Corresponds to the JSON property diffDownloadResponse
1082 1083 1084 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1082 def diff_download_response @diff_download_response end |
#diff_upload_request ⇒ Google::Apis::CloudsupportV2beta::DiffUploadRequest
gdata.* are outside protos with mising documentation
Corresponds to the JSON property diffUploadRequest
1087 1088 1089 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1087 def diff_upload_request @diff_upload_request end |
#diff_upload_response ⇒ Google::Apis::CloudsupportV2beta::DiffUploadResponse
gdata.* are outside protos with mising documentation
Corresponds to the JSON property diffUploadResponse
1092 1093 1094 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1092 def diff_upload_response @diff_upload_response end |
#diff_version_response ⇒ Google::Apis::CloudsupportV2beta::DiffVersionResponse
gdata.* are outside protos with mising documentation
Corresponds to the JSON property diffVersionResponse
1097 1098 1099 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1097 def diff_version_response @diff_version_response end |
#download_parameters ⇒ Google::Apis::CloudsupportV2beta::DownloadParameters
gdata.* are outside protos with mising documentation
Corresponds to the JSON property downloadParameters
1102 1103 1104 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1102 def download_parameters @download_parameters end |
#filename ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property filename
1107 1108 1109 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1107 def filename @filename end |
#hash_prop ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property hash
1112 1113 1114 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1112 def hash_prop @hash_prop end |
#hash_verified ⇒ Boolean Also known as: hash_verified?
gdata.* are outside protos with mising documentation
Corresponds to the JSON property hashVerified
1117 1118 1119 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1117 def hash_verified @hash_verified end |
#inline ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property inline
NOTE: Values are automatically base64 encoded/decoded in the client library.
1124 1125 1126 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1124 def inline @inline end |
#is_potential_retry ⇒ Boolean Also known as: is_potential_retry?
gdata.* are outside protos with mising documentation
Corresponds to the JSON property isPotentialRetry
1129 1130 1131 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1129 def is_potential_retry @is_potential_retry end |
#length ⇒ Fixnum
gdata.* are outside protos with mising documentation
Corresponds to the JSON property length
1135 1136 1137 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1135 def length @length end |
#md5_hash ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property md5Hash
NOTE: Values are automatically base64 encoded/decoded in the client library.
1141 1142 1143 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1141 def md5_hash @md5_hash end |
#media_id ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property mediaId
NOTE: Values are automatically base64 encoded/decoded in the client library.
1147 1148 1149 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1147 def media_id @media_id end |
#object_id_prop ⇒ Google::Apis::CloudsupportV2beta::ObjectIdProp
gdata.* are outside protos with mising documentation
Corresponds to the JSON property objectId
1152 1153 1154 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1152 def object_id_prop @object_id_prop end |
#path ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property path
1157 1158 1159 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1157 def path @path end |
#reference_type ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property referenceType
1162 1163 1164 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1162 def reference_type @reference_type end |
#sha1_hash ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property sha1Hash
NOTE: Values are automatically base64 encoded/decoded in the client library.
1168 1169 1170 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1168 def sha1_hash @sha1_hash end |
#sha256_hash ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property sha256Hash
NOTE: Values are automatically base64 encoded/decoded in the client library.
1174 1175 1176 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1174 def sha256_hash @sha256_hash end |
#sha512_hash ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property sha512Hash
NOTE: Values are automatically base64 encoded/decoded in the client library.
1180 1181 1182 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1180 def sha512_hash @sha512_hash end |
#timestamp ⇒ Fixnum
gdata.* are outside protos with mising documentation
Corresponds to the JSON property timestamp
1185 1186 1187 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1185 def @timestamp end |
#token ⇒ String
gdata.* are outside protos with mising documentation
Corresponds to the JSON property token
1190 1191 1192 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1190 def token @token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1197 def update!(**args) @algorithm = args[:algorithm] if args.key?(:algorithm) @bigstore_object_ref = args[:bigstore_object_ref] if args.key?(:bigstore_object_ref) @blob_ref = args[:blob_ref] if args.key?(:blob_ref) @blobstore2_info = args[:blobstore2_info] if args.key?(:blobstore2_info) @composite_media = args[:composite_media] if args.key?(:composite_media) @content_type = args[:content_type] if args.key?(:content_type) @content_type_info = args[:content_type_info] if args.key?(:content_type_info) @cosmo_binary_reference = args[:cosmo_binary_reference] if args.key?(:cosmo_binary_reference) @crc32c_hash = args[:crc32c_hash] if args.key?(:crc32c_hash) @diff_checksums_response = args[:diff_checksums_response] if args.key?(:diff_checksums_response) @diff_download_response = args[:diff_download_response] if args.key?(:diff_download_response) @diff_upload_request = args[:diff_upload_request] if args.key?(:diff_upload_request) @diff_upload_response = args[:diff_upload_response] if args.key?(:diff_upload_response) @diff_version_response = args[:diff_version_response] if args.key?(:diff_version_response) @download_parameters = args[:download_parameters] if args.key?(:download_parameters) @filename = args[:filename] if args.key?(:filename) @hash_prop = args[:hash_prop] if args.key?(:hash_prop) @hash_verified = args[:hash_verified] if args.key?(:hash_verified) @inline = args[:inline] if args.key?(:inline) @is_potential_retry = args[:is_potential_retry] if args.key?(:is_potential_retry) @length = args[:length] if args.key?(:length) @md5_hash = args[:md5_hash] if args.key?(:md5_hash) @media_id = args[:media_id] if args.key?(:media_id) @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop) @path = args[:path] if args.key?(:path) @reference_type = args[:reference_type] if args.key?(:reference_type) @sha1_hash = args[:sha1_hash] if args.key?(:sha1_hash) @sha256_hash = args[:sha256_hash] if args.key?(:sha256_hash) @sha512_hash = args[:sha512_hash] if args.key?(:sha512_hash) @timestamp = args[:timestamp] if args.key?(:timestamp) @token = args[:token] if args.key?(:token) end |