Class: Google::Apis::CloudsupportV2beta::SupportEventSubscription
- Inherits:
-
Object
- Object
- Google::Apis::CloudsupportV2beta::SupportEventSubscription
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsupport_v2beta/classes.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb,
lib/google/apis/cloudsupport_v2beta/representations.rb
Overview
A support event subscription.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#failure_reason ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#pub_sub_topic ⇒ String
Required.
-
#purge_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SupportEventSubscription
constructor
A new instance of SupportEventSubscription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SupportEventSubscription
Returns a new instance of SupportEventSubscription.
1410 1411 1412 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1410 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the subscription was created.
Corresponds to the JSON property createTime
1371 1372 1373 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1371 def create_time @create_time end |
#delete_time ⇒ String
Output only. The time at which the subscription was deleted.
Corresponds to the JSON property deleteTime
1376 1377 1378 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1376 def delete_time @delete_time end |
#failure_reason ⇒ String
Output only. Reason why subscription is failing. State of subscription must be
FAILING in order for this to have a value.
Corresponds to the JSON property failureReason
1382 1383 1384 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1382 def failure_reason @failure_reason end |
#name ⇒ String
Identifier. The resource name of the support event subscription.
Corresponds to the JSON property name
1387 1388 1389 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1387 def name @name end |
#pub_sub_topic ⇒ String
Required. The name of the Pub/Sub topic to publish notifications to. Format:
projects/project/topics/topic
Corresponds to the JSON property pubSubTopic
1393 1394 1395 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1393 def pub_sub_topic @pub_sub_topic end |
#purge_time ⇒ String
Output only. The time at which the subscription will be purged.
Corresponds to the JSON property purgeTime
1398 1399 1400 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1398 def purge_time @purge_time end |
#state ⇒ String
Output only. The state of the subscription.
Corresponds to the JSON property state
1403 1404 1405 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1403 def state @state end |
#update_time ⇒ String
Output only. The time at which the subscription was last updated.
Corresponds to the JSON property updateTime
1408 1409 1410 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1408 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 |
# File 'lib/google/apis/cloudsupport_v2beta/classes.rb', line 1415 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @name = args[:name] if args.key?(:name) @pub_sub_topic = args[:pub_sub_topic] if args.key?(:pub_sub_topic) @purge_time = args[:purge_time] if args.key?(:purge_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |